# Starlette Auth

Authentication library for Starlette.

![PyPI](https://img.shields.io/pypi/v/starlette_auth)
![GitHub](https://img.shields.io/github/license/alex-oleshkevich/starlette_auth)
![Libraries.io dependency status for latest release](https://img.shields.io/librariesio/release/pypi/starlette_auth)
![PyPI - Downloads](https://img.shields.io/pypi/dm/starlette_auth)
![GitHub Release Date](https://img.shields.io/github/release-date/alex-oleshkevich/starlette_auth)

## Installation

Install `starlette_auth` using PIP or poetry:

```bash
pip install starlette_auth
```

## Features

- __Vanilla Starlette integration.__ Following standards ensures compatibility with other libraries.
- __Multiple backends.__ Supports multiple authentication backends (e.g. database, OAuth, etc.)
- __Remember me.__ Persistent sessions with expiration time.
- __Middleware__ to protect route segments.
- Session fixation protection

## Quick start

See example application in [examples/](examples/) directory of this repository.
